# Copyright 2013-2023 Lawrence Livermore National Security, LLC and other
# Spack Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)

from spack import *


class PyPyunicore(PythonPackage):
    """Python library for using the UNICORE REST API"""

    homepage = "https://github.com/HumanBrainProject/pyunicore"
    pypi     = "pyunicore/pyunicore-0.14.1.tar.gz"

    maintainers = ['bschulle', 'elmath']

    version('0.14.1', sha256='7efd4784d55ef02c4da4431232b54505814666577165c0f320c922ed2b32af01')
    version('0.14.0', sha256='8197aea4009ceb150bc4e341f660c942e424dca5025bc0253c8729328835a0c0')
    version('0.12.0', sha256='a1d7a63528cb0065d5ad58a42bc00adcf48614e16c2337dd815c8ac4d81b60cb')
    version('0.11.4', sha256='519b23a56103c1d8dd7d9a76029785dd89aa424de8bf9df345baf591f816553c')
    version('0.11.3', sha256='bb5582107daff9ddb6444f35eff019791009f04927508c4c9ae918f22effb718')

    variant("fuse",   default=False, description="Use the UFTP fuse driver")
    variant("fs",     default=False, description="Use UFTP with pyfilesystem")
    variant("crypto", default=False, description="Create JWT tokens signed with keys")

    depends_on('py-setuptools',          type='build')
    depends_on('py-pyjwt@2.0:',          type=('build', 'run'))
    depends_on('py-requests@2.5:',       type=('build', 'run'))
    depends_on('py-fusepy@3.0.1:',       type=('build', 'run'), when='+fuse')
    depends_on('py-fs@2.4.0:',           type=('build', 'run'), when='+fs')
    depends_on('py-cryptography@3.3.1:', type=('build', 'run'), when='+crypto')
    depends_on('py-pytest',              type=('test'))
